==> jboss-3.2.6-src.tar.bz2: jboss-3.2.6-src/jaxrpc/src/main/org/apache/axis/message/SOAPEnvelopeImpl.java <==
/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.axis.message;

// $Id: SOAPEnvelopeImpl.java,v 1.1.1.1 2004/08/20 18:43:58 tdiesler Exp $

import org.apache.axis.NotImplementedException;
import org.apache.axis.components.logger.LogFactory;
import org.apache.commons.logging.Log;

import javax.xml.soap.Name;
import javax.xml.soap.SOAPBody;
import javax.xml.soap.SOAPElement;
import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeader;

/**
 * An implemenation of the abstract SOAPEnvelope.
 * <p/>
 * This class should not expose functionality that is not part of
 * {@link SOAPEnvelope}. Client code should use <code>SOAPEnvelope</code> whenever possible.
 *
 * @author Thomas Diesler (thomas.diesler@jboss.org)
 */
public class SOAPEnvelopeImpl extends SOAPElementAxisImpl implements SOAPEnvelope
{
   private static Log log = LogFactory.getLog(SOAPEnvelopeImpl.class.getName());

   public SOAPEnvelopeImpl(String localPart, String prefix, String uri)
   {
      super(localPart, prefix, uri);
   }

   public SOAPBody addBody() throws SOAPException
   {
      throw new NotImplementedException();
   }

   public SOAPHeader addHeader() throws SOAPException
   {
      throw new NotImplementedException();
   }

   public Name createName(String localName) throws SOAPException
   {
      throw new NotImplementedException();
   }

   public Name createName(String localName, String prefix, String uri) throws SOAPException
   {
      throw new NotImplementedException();
   }

   public SOAPBody getBody() throws SOAPException
   {
      throw new NotImplementedException();
   }

   public SOAPHeader getHeader() throws SOAPException
   {
      throw new NotImplementedException();
   }

   /**
    * Text nodes are not supported.
    */
   public SOAPElement addTextNode(String s) throws SOAPException
   {
      throw new SOAPException("Cannot add Text node to SOAPEnvelope");
   }
}

==> jboss-3.2.7-src.tar.bz2: jboss-3.2.7-src/jaxrpc/src/main/org/apache/axis/message/SOAPEnvelopeImpl.java <==
/*
 * Copyright 2001-2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.axis.message;

// $Id: SOAPEnvelopeImpl.java,v 1.1.1.1.2.1 2004/11/05 14:56:42 tdiesler Exp $

import org.apache.axis.NotImplementedException;
import org.jboss.logging.Logger;

import javax.xml.soap.Name;
import javax.xml.soap.SOAPBody;
import javax.xml.soap.SOAPElement;
import javax.xml.soap.SOAPEnvelope;
import javax.xml.soap.SOAPException;
import javax.xml.soap.SOAPHeader;

/**
 * An implemenation of the abstract SOAPEnvelope.
 * <p/>
 * This class should not expose functionality that is not part of
 * {@link SOAPEnvelope}. Client code should use <code>SOAPEnvelope</code> whenever possible.
 *
 * @author Thomas Diesler (thomas.diesler@jboss.org)
 */
public class SOAPEnvelopeImpl extends SOAPElementAxisImpl implements SOAPEnvelope
{
   private static Logger log = Logger.getLogger(SOAPEnvelopeImpl.class.getName());

   public SOAPEnvelopeImpl(String localPart, String prefix, String uri)
   {
      super(localPart, prefix, uri);
   }

   public SOAPBody addBody() throws SOAPException
   {
      throw new NotImplementedException();
   }

   public SOAPHeader addHeader() throws SOAPException
   {
      throw new NotImplementedException();
   }

   public Name createName(String localName) throws SOAPException
   {
      throw new NotImplementedException();
   }

   public Name createName(String localName, String prefix, String uri) throws SOAPException
   {
      throw new NotImplementedException();
   }

   public SOAPBody getBody() throws SOAPException
   {
      throw new NotImplementedException();
   }

   public SOAPHeader getHeader() throws SOAPException
   {
      throw new NotImplementedException();
   }

   /**
    * Text nodes are not supported.
    */
   public SOAPElement addTextNode(String s) throws SOAPException
   {
      throw new SOAPException("Cannot add Text node to SOAPEnvelope");
   }
}
